@@ -1,7 +1,7 @@
 <?php
 /*
     Squirrelmail plugin setup file.
-    Copyright 2003, 2004 Daniel K. Imori
+    Copyright 2003-2008 Daniel K. Imori
 
     This file is part of vkeyboard plugin.
 
@@ -41,7 +41,7 @@ function plugin_vkeyboard_main()
 
 function vkeyboard_version()
 {
-    return '0.8';
+    return '0.9.1';
 }
 
 ?>
